| DensityGenerator.normalize | R Documentation |
The function DensityGenerator.normalize transforms an elliptical copula generator
into an elliptical copula generator,generating the same distribution
and which is normalized to follow the normalization constraint
\frac{\pi^{d/2}}{\Gamma(d/2)}
\int_0^{+\infty} g_k(t) t^{(d-2)/2} dt = 1.
as well as the identification constraint
\frac{\pi^{(d-1)/2}}{\Gamma((d-1)/2)}
\int_0^{+\infty} g_k(t) t^{(d-3)/2} dt = b.
The function DensityGenerator.check checks, for a given generator,
whether these two constraints are satisfied.
DensityGenerator.normalize(grid, grid_g, d, verbose = 0, b = 1)
DensityGenerator.check(grid, grid_g, d, b = 1)
grid |
the regularly spaced grid on which the values of the generator are given. |
grid_g |
the values of the |
d |
the dimension of the space. |
verbose |
if 1, prints the estimated (alpha, beta) such that
|
b |
the target value for the identification constraint. |
DensityGenerator.normalize returns
the normalized generator, as a list of values on the same grid.
DensityGenerator.check returns (invisibly) a vector of two booleans
where the first element is TRUE if the normalization constraint is satisfied
and the second element is TRUE if the identification constraint is satisfied.
Derumigny, A., & Fermanian, J. D. (2022). Identifiability and estimation of meta-elliptical copula generators. Journal of Multivariate Analysis, article 104962. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.jmva.2022.104962")}.
EllCopSim() for the simulation of elliptical copula samples,
EllCopEst() for the estimation of elliptical copula,
conversion functions for the conversion between different representation
of the generator of an elliptical copula.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.