compute_matrix_alpha: Compute the matrix of coefficients alpha
Description
This matrix of coefficient is useful for the estimation of higher-order
derivatives of an elliiptical distribution density generator. It is introduced
in Section 3 of (Ryan and Derumigny, 2024).
Usage
compute_matrix_alpha(kmax, grid, a, d)
Value
a (kmax+1) * (kmax+1) * length(grid) array
Arguments
kmax
order the derivative that we want to compute
grid
the grid of the values at which we want to compute the derivative
a
the tuning parameter controlling the bias of the estimator
at zero.
d
the dimension of the problem
Author
Victor Ryan, Alexis Derumigny
References
Ryan, V., & Derumigny, A. (2024).
On the choice of the two tuning parameters for nonparametric estimation of an
elliptical distribution generator
arxiv:2408.17087.
See Also
This function uses the internal functions derivative.tau
and derivative.psi.
See also vectorized_Faa_di_Bruno.