View source: R/zz_auxiliaryFunctions.R
| derivative.psi | R Documentation |
\psi, its inverse \Psi and the k-th derivative of \PsiThe function \psi is used to estimate the generator of elliptical distribution.
It depends on the parameter a, which reduces the bias of the estimator around zero.
The functions f1 and f2 are already implemented in derivative.psi.
They are required to compute higher derivatives of \Psi.
derivative.psi(x, a, d, k, inverse)
f1(x, d, k = 0)
f2(x, a, d, k = 0)
x |
a numeric value |
a |
a parameter |
d |
the dimension of the data |
k |
the order of derivative.
If |
inverse |
if |
A numeric value \psi(x)^{(k)} if inverse = TRUE,
otherwise \Psi(x)^{(k)}.
The functions f1 and f2 also return a numeric value
f1(): f_1(x) = x^{2/d}
f2(): f_2(x) = (x + a)^{d/2} - a^{d/2}
The derivatives of \psi is not yet implemented. The function \psi
is defined as \psi(x) = -a + (a^{d/2} + x^{d/2})^{2/d}.
For any a > 0 and x > 0, it has an inverse.
Let \Psi be the inverse function of \psi, then
\Psi(x) = ((x+a)^{d/2} - a^{d/2})^{2/d} = (f_1 \circ f_2)(x).
Victor Ryan, Alexis Derumigny
Ryan, V., & Derumigny, A. (2024). On the choice of the two tuning parameters for nonparametric estimation of an elliptical distribution generator arxiv:2408.17087.
derivative.tau and derivative.rho.
vectorized_Faa_di_Bruno which is used for the computation
of the derivatives.
# Return the 5-th derivative of the inverse of psi
derivative.psi(x = 1, a = 1, d = 3, k = 5, inverse = TRUE)
# Return psi
derivative.psi(x = 1, a = 1, d = 3, k = 0, inverse = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.