Learn R Programming

ElliptCopulas (version 0.1.4.1)

derivative.rho: Computing \(\rho\) and its \(k\)-th derivative

Description

The function \(\rho\) is used to compute \(\widetilde{AMSE}\). The quantity \(\widetilde{AMSE}\) is of interest because we can use it to find the optimal \(a\).

Usage

derivative.rho(grid, a, d, k, derivatives.g)

Value

a numeric vector \(\rho(grid[1])^{(k)}, \dots, \rho(grid[N])^{(k)}\), where \(N\) is the length of the grid

Arguments

grid

a grid of numeric values

a

a parameter \(a > 0\) that reduces the bias of the estimator around zero

d

the dimension of the data

k

the order of derivative of \(\rho\). If k = 0, then the original function value is returned. If k > 0, the value of its derivative is returned

derivatives.g

a matrix of size length(x) * (k + 1) whose entry of position [i,j] is \(g^{(j - 1)} (x[i])\)

Author

Victor Ryan, Alexis Derumigny

References

Ryan, V., & Derumigny, A. (2024). On the choice of the two tuning parameters for nonparametric estimation of an elliptical distribution generator arxiv:2408.17087.

See Also

derivative.tau and derivative.psi. EllDistrDerivEst for the nonparametric estimation of the derivatives of g, the elliptical distribution density generator. compute_matrix_alpha which is used for the computation of the derivatives.

Examples

Run this code

# Return the 5-th derivative of tau at x = 1

grid = c(1)
a = 1; d = 3; k = 3
der.g = matrix(seq(1, 3, length.out = 4), nrow = 1)
derivative.rho(grid = grid, a = a, d = d, k = k, derivatives.g = der.g)

Run the code above in your browser using DataLab