View source: R/zz_auxiliaryFunctions.R
| derivative.tau | R Documentation |
\tau and its k-th derivativeThe function \tau is used to compute \alpha_{i,k},
which is required to compute the derivatives
of the generator of elliptical distribution.
The functions f3 and f4 are already implemented in derivative.tau.
These functions are needed for computing higher derivatives of \tau.
derivative.tau(x, a, d, k)
f3(x, d, k = 0)
f4(x, a, d, k = 0)
x |
a numeric vector |
a |
a parameter |
d |
the dimension of the data |
k |
the order of derivatives for |
A numeric vector \tau^{(k)}(x_1), ..., \tau^{(k)}(x_N)
where N = length(x).
The functions f3 and f4 also return a numeric value
f3(): f_3(x) = x^{(d-2)/d}
f4(): f_4(x) = a^{d/2} + x^{d/2}
The function \tau is defined as follows:
\tau(x) = x^{(d-2)/2}/\psi^{\prime}(x), where
\psi^{\prime}(x) = x^{d/2 - 1}(a^{d/2} + x^{d/2})^{2/d - 1}.
The definition of \psi is already described in derivative.tau.
Therefore, by the definition of f_3 and f_4,
the function \tau is actually \tau(x) = (f_3 \circ f_4)(x).
Victor Ryan, Alexis Derumigny
Ryan, V., & Derumigny, A. (2024). On the choice of the two tuning parameters for nonparametric estimation of an elliptical distribution generator arxiv:2408.17087.
derivative.psi and derivative.rho.
vectorized_Faa_di_Bruno which is used for the computation
of the derivatives.
# Return the 5-th derivative of tau at x = 1
derivative.tau(x = 1, a = 1, d = 3, k = 5)
# Return the value of tau at x = 1.
derivative.tau(x = 1, a = 1, d = 3, k = 0)
# Vectorized version
derivative.tau(x = c(1,3), a = 1, d = 3, k = 5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.