derivative.psi: Computing \(\psi\), its inverse \(\Psi\) and the \(k\)-th derivative of \(\Psi\)
Description
The function \(\psi\) is used to estimate the generator of elliptical distribution.
It depends on the parameter \(a\), which reduces the bias of the estimator around zero.
The functions f1 and f2 are already implemented in derivative.psi.
They are required to compute higher derivatives of \(\Psi\).
Usage
derivative.psi(x, a, d, k, inverse)
f1(x, d, k = 0)
f2(x, a, d, k = 0)
Value
A numeric value \(\psi(x)^{(k)}\) if inverse = TRUE,
otherwise \(\Psi(x)^{(k)}\).
The functions f1 and f2 also return a numeric value
Arguments
x
a numeric value
a
a parameter \(a > 0\) that reduces the bias of the estimator around zero
d
the dimension of the data
k
the order of derivative.
If k = 0, then the original function value is returned.
If k > 0, the value of its derivative is returned.
inverse
if inverse = TRUE, then the inverse of \(\Psi\) is
of interest. Otherwise, the function \(\psi\) is used for the computation
Functions
f1(): \(f_1(x) = x^{2/d}\)
f2(): \(f_2(x) = (x + a)^{d/2} - a^{d/2}\)
Author
Victor Ryan, Alexis Derumigny
References
Ryan, V., & Derumigny, A. (2024).
On the choice of the two tuning parameters for nonparametric estimation of an
elliptical distribution generator
arxiv:2408.17087.
See Also
derivative.tau and derivative.rho.
vectorized_Faa_di_Bruno which is used for the computation
of the derivatives.
# Return the 5-th derivative of the inverse of psiderivative.psi(x = 1, a = 1, d = 3, k = 5, inverse = TRUE)
# Return psiderivative.psi(x = 1, a = 1, d = 3, k = 0, inverse = FALSE)