Learn R Programming

ElliptCopulas (version 0.1.4.1)

derivative.tau: Computing \(\tau\) and its \(k\)-th derivative

Description

The function \(\tau\) is used to compute \(\alpha_{i,k}\), which is required to compute the derivatives of the generator of elliptical distribution. The functions f3 and f4 are already implemented in derivative.tau. These functions are needed for computing higher derivatives of \(\tau\).

Usage

derivative.tau(x, a, d, k)

f3(x, d, k = 0)

f4(x, a, d, k = 0)

Value

A numeric vector \(\tau^{(k)}(x_1), ..., \tau^{(k)}(x_N)\)

where N = length(x).

The functions f3 and f4 also return a numeric value

Arguments

x

a numeric vector

a

a parameter \(a > 0\) that reduces the bias of the estimator around zero

d

the dimension of the data

k

the order of derivatives for f3 and f4

Functions

  • f3(): \(f_3(x) = x^{(d-2)/d}\)

  • f4(): \(f_4(x) = a^{d/2} + x^{d/2}\)

Author

Victor Ryan, Alexis Derumigny

References

Ryan, V., & Derumigny, A. (2024). On the choice of the two tuning parameters for nonparametric estimation of an elliptical distribution generator arxiv:2408.17087.

See Also

derivative.psi and derivative.rho. vectorized_Faa_di_Bruno which is used for the computation of the derivatives.

Examples

Run this code

# Return the 5-th derivative of tau at x = 1
derivative.tau(x = 1, a = 1, d = 3, k = 5)

# Return the value of tau at x = 1.
derivative.tau(x = 1, a = 1, d = 3, k = 0)

# Vectorized version
derivative.tau(x = c(1,3), a = 1, d = 3, k = 5)

Run the code above in your browser using DataLab